@@ -1,2 +1,2 @@
-from .generic import whoami, shell, extension
 from .finders import find_objects, is_tool, tools_requirements
+from .generic import extension, shell, whoami
